prom

package
v0.0.0-...-dfddab7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	NamespaceMatchName         = "namespace"
	ExportedNamespaceMatchName = "exported_namespace"
)

Variables

This section is empty.

Functions

func FilterLabelMatchers

func FilterLabelMatchers(namespaceSet data.Set, srcMatchers []*prompb.LabelMatcher) []*prompb.LabelMatcher

func FilterMatchers

func FilterMatchers(namespaceSet data.Set, srcMatchers []*promlb.Matcher, label string) []*promlb.Matcher

FilterMatchers updates the prometheus matchers to include the passed label matcher. If the passed label matches one of the predefined ones, the matchers' value will be updated to contain only the namespaceSet.

func NewExprForCountAllLabels

func NewExprForCountAllLabels(namespaces []string) string

func NewInstantVectorSelectorsForNamespaces

func NewInstantVectorSelectorsForNamespaces(namespaces []string) string

Types

This section is empty.

Jump to