Documentation
¶
Index ¶
- Constants
- func FilterLabelMatchers(namespaceSet data.Set, srcMatchers []*prompb.LabelMatcher) []*prompb.LabelMatcher
- func FilterMatchers(namespaceSet data.Set, srcMatchers []*promlb.Matcher, label string) []*promlb.Matcher
- func NewExprForCountAllLabels(namespaces []string) string
- func NewInstantVectorSelectorsForNamespaces(namespaces []string) string
Constants ¶
const ( NamespaceMatchName = "namespace" ExportedNamespaceMatchName = "exported_namespace" )
Variables ¶
This section is empty.
Functions ¶
func FilterLabelMatchers ¶
func FilterLabelMatchers(namespaceSet data.Set, srcMatchers []*prompb.LabelMatcher) []*prompb.LabelMatcher
func FilterMatchers ¶
func FilterMatchers(namespaceSet data.Set, srcMatchers []*promlb.Matcher, label string) []*promlb.Matcher
FilterMatchers updates the prometheus matchers to include the passed label matcher. If the passed label matches one of the predefined ones, the matchers' value will be updated to contain only the namespaceSet.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.